/***************************************************************************
                          filebrowser.cpp  -  description
                             -------------------
    begin                : Sun Feb 11 2001
    copyright            : (C) 2001 by Matthias Welwarsky
    email                : matze@stud.fbi.fh-darmstadt.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qlayout.h>
#include <qfileinfo.h>
#include <qstringlist.h>

#include <kdebug.h>
#include <kfilereader.h>
#include <kfiledetailview.h>
#include <ktoolbar.h>
#include <kcombobox.h>
#include <kdiroperator.h>

#include "filebrowser.h"

FileBrowser::FileBrowser(QWidget *parent, const char *name ) : QWidget(parent,name) {
	init();
}

FileBrowser::~FileBrowser(){
}

/** initialise internals */
void FileBrowser::init(){
	QVBoxLayout* layout = new QVBoxLayout(this);
	
	KToolBar* toolBar = new KToolBar(this, "toolBar");
	layout->add(toolBar);
		
	dirOperator = new KDirOperator(KURL(), this, "dirOperator");
	dirOperator->setNameFilter("*.bmp");
	dirOperator->setView(KFile::Detail);
	dirOperator->setMode(KFile::File);
	dirOperator->clearHistory();
	dirOperator->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
	
	KActionCollection* coll = dirOperator->actionCollection();
    coll->action( "up" )->plug( toolBar );
    coll->action( "back" )->plug( toolBar );
    coll->action( "forward" )->plug( toolBar );
    coll->action( "home" )->plug( toolBar );
    coll->action( "reload" )->plug( toolBar );	
	layout->add(dirOperator);
	
	connect(dirOperator, SIGNAL(fileSelected(const KFileViewItem*)), this, SLOT(executed(const KFileViewItem*)));
}

/** No descriptions */
void FileBrowser::executed(const KFileViewItem* item){
	// Implement reading the file and displaying the preview
	emit selected(item->urlString().mid(5));
}

/** No descriptions */
void FileBrowser::setDirectory(const QString& dir){
	KURL url = dir;
	dirOperator->setURL(url, false);
}

/** set the directory where the browsing starts */
void FileBrowser::setDirectory(const QDir& dir){
	KURL url = dir.path();
	dirOperator->setURL(url, false);
}
